/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package ui.component.table.model;

import domain.Invoice;
import domain.InvoiceItem;
import domain.Product;
import java.math.BigDecimal;
import javax.swing.table.AbstractTableModel;

/**
 *
 * @author student1
 */
public class InvoiceTableModel extends AbstractTableModel {

    private final Invoice invoice;
    private String[] columnNames = new String[]{"Order No", "Product", "Unit", "Price", "Quantity", "Total"};

    public InvoiceTableModel(Invoice invoice) {
        this.invoice = invoice;
    }

    @Override
    public int getRowCount() {
        if (invoice != null) {
            return invoice.getItems().size();
        }
        return 0;
    }

    @Override
    public int getColumnCount() {
        return columnNames.length;
    }

    @Override
    public String getColumnName(int columnIndex) {
        return columnNames[columnIndex];
    }

    @Override
    public Object getValueAt(int rowIndex, int columnIndex) {
        InvoiceItem item = invoice.getItems().get(rowIndex);
        switch (columnIndex) {
            case 0:
                return item.getOrderNo();
            case 1:
                return item.getProduct().getName();
            case 2:
                return item.getProduct().getMeasurementUnit();
            case 3:
                return item.getProduct().getPrice();
            case 4:
                return item.getQuantity();
            case 5:
                return item.getQuantity().multiply(item.getProduct().getPrice());
            default:
                return "n/a";
        }
    }

    public void addInvoiceItem(Product product, BigDecimal quantity) {
        InvoiceItem item = new InvoiceItem();
        item.setOrderNo(Long.valueOf(invoice.getItems().size() + 1));
        item.setProduct(product);
        item.setPrice(product.getPrice());
        item.setQuantity(quantity);
        invoice.getItems().add(item);
        System.out.println("Added new invoice item!");
        //fireTableDataChanged();
        fireTableRowsInserted(invoice.getItems().size() - 1, invoice.getItems().size() - 1);
    }

    public void removeInvoiceItem(int index) {
        invoice.getItems().remove(index);
        setOrderNumbers();
        fireTableRowsDeleted(invoice.getItems().size() - 1, invoice.getItems().size() - 1);
    }

    private void setOrderNumbers() {
        long orderNo = 0;
        for (InvoiceItem item : invoice.getItems()) {
            item.setOrderNo(++orderNo);
        }
    }

    public Invoice getInvoice() {
        return invoice;
    }

}
